pilas.actores.menu

Package pilas :: Package actores :: Module menu |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.menu

      1  # -*- encoding: utf-8 -*-
      2  # Pilas engine - A video game framework.
      3  #
      4  # Copyright 2010 - Hugo Ruscitti
      5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
      6  #
      7  # Website - http://www.pilas-engine.com.ar
      8
      9  from pilas.actores import Actor
     10  import pilas
     11
     12  DEMORA = 14
     13
    156